Light weight package to read and exploit km3net compass data
============================================================

.. image:: https://git.km3net.de/km3py/km3compass/badges/master/pipeline.svg
    :target: https://git.km3net.de/km3py/km3compass/pipelines

.. image:: https://git.km3net.de/km3py/km3compass/badges/master/coverage.svg
    :target: https://km3py.pages.km3net.de/km3compass/coverage

.. image:: https://git.km3net.de/examples/km3badges/-/raw/master/docs-latest-brightgreen.svg
    :target: https://km3py.pages.km3net.de/km3compass


Setup
=====

Currently, only solution is to install the repository from source.
After cloning the repository, you can install it with pip (preferably inside a virtual env).
From inside the repository:


.. code:: bash

   pip install ./

And you are done !


Command line interface
======================

This package provides some command line tool that can be used to interact with compass data.




Acknowledgements
================

Thanks especially to the gracious help of all contributors:

Valentin Pestel, Tamas Gal, Cristiano Bozza, Bryan Darquea, Jhilik Majumdar

